@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_iam._jsii
@@ -17,9 +17,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-synthetics",
-    "1.61.1",
+    "1.66.0",
     __name__[0:-6],
-    "aws-synthetics@1.61.1.jsii.tgz",
+    "aws-synthetics@1.66.0.jsii.tgz",
 )
 
 __all__ = [
